==> react-common-bootstrap-2.0.15.tgz: package/form/CustomFormFieldAsyncSelect.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import _ from 'lodash';
import React, { useCallback } from 'react';
import AsyncSelect from 'react-select/async';
import Http from '../services/Http';
const CustomFormFieldAsyncSelect = ({
  label = '',
  value,
  onChange,
  getUrl,
  format,
  placeholder = '',
  noOptionsMessage = () => 'Aucun résultat',
  multi = false,
  disabled = false,
  isValid = true,
  className = '',
  ...props
}) => {
  const loadOptions = (inputValue, callback) => callApi(inputValue, callback);
  const callApi = useCallback(_.debounce((inputValue, callback) => {
    Http.get(getUrl(inputValue)).then(utilisateurs => callback(utilisateurs.map(format)));
  }, 500), []);
  return /*#__PURE__*/React.createElement("div", null, label != '' && /*#__PURE__*/React.createElement("label", null, label), /*#__PURE__*/React.createElement(AsyncSelect, _extends({
    value: value,
    onChange: val => onChange(multi ? val.map(v => v.value) : val),
    loadOptions: loadOptions,
    noOptionsMessage: ({
      inputValue
    }) => noOptionsMessage(inputValue),
    placeholder: placeholder,
    isDisabled: disabled,
    className: `react-select ${!isValid && displayError ? 'is-invalid' : ''} ${className}`
  }, props)));
};
export default CustomFormFieldAsyncSelect;

==> react-common-bootstrap-2.0.21.tgz: package/form/CustomFormFieldAsyncSelect.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import _ from 'lodash';
import React, { useCallback } from 'react';
import AsyncSelect from 'react-select/async';
import Http from '../services/Http';
const CustomFormFieldAsyncSelect = ({
  label = '',
  value,
  onChange,
  getUrl,
  format,
  placeholder = '',
  noOptionsMessage = () => 'Aucun résultat',
  multi = false,
  disabled = false,
  isValid = true,
  className = '',
  filterOptions = option => option,
  ...props
}) => {
  const loadOptions = (inputValue, callback) => callApi(inputValue, callback);
  const callApi = useCallback(_.debounce((inputValue, callback) => {
    Http.get(getUrl(inputValue)).then(utilisateurs => callback(utilisateurs.filter(filterOptions).map(format)));
  }, 500), []);
  return /*#__PURE__*/React.createElement("div", null, label != '' && /*#__PURE__*/React.createElement("label", null, label), /*#__PURE__*/React.createElement(AsyncSelect, _extends({
    value: value,
    onChange: val => onChange(multi ? val.map(v => v.value) : val),
    loadOptions: loadOptions,
    noOptionsMessage: ({
      inputValue
    }) => noOptionsMessage(inputValue),
    placeholder: placeholder,
    isDisabled: disabled,
    className: `react-select ${!isValid && displayError ? 'is-invalid' : ''} ${className}`
  }, props)));
};
export default CustomFormFieldAsyncSelect;
